==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/caction.cpp <==
/***************************************************************************
                          caction.cpp  -  action toolbar item
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Ne nov 3 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@host.sk
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "caction.h"

#include "kmuddy.h"
#include "ccmdprocessor.h"
#include "csession.h"

extern KMuddy *kmuddy;

#include <kconfig.h>
#include <ktoolbar.h>
#include <ktoolbarbutton.h>

cAction::cAction ()
{
  caption = "";
  command = "";
  iconname = "";
  command2 = "";
  pushdown = false;
  toolbar = kmuddy->atool ();
  index = -1;
}

cAction::~cAction ()
{
  //NOTHING!
}

cSaveableField *cAction::newInstance ()
{
  return new cAction;
}

void cAction::load (KConfig *config, const QString &group)
{
  config->setGroup (group);
  caption = config->readEntry ("Caption", "cmd_placeholder");
  command = config->readEntry ("Command", "");
  iconname = config->readEntry ("Icon name", "unknown");
  pushdown = config->readBoolEntry ("Pushdown", false);
  command2 = config->readEntry ("Command2", "");
  
}

void cAction::save (KConfig *config, const QString &group)
{
  config->setGroup (group);
  config->writeEntry ("Caption", caption);
  config->writeEntry ("Command", command);
  config->writeEntry ("Icon name", iconname);
  config->writeEntry ("Pushdown", pushdown);
  config->writeEntry ("Command2", command2);
}

void cAction::setCaption (const QString &s)
{
  caption = s;
}

QString cAction::getCaption ()
{
  return caption;
}

void cAction::setCommand (const QString &s)
{
  command = s;
}

void cAction::setCommand2 (const QString &s)
{
  command2 = s;
}

void cAction::setPushDown (bool how)
{
  pushdown = how;
}

bool cAction::isPushDown ()
{
  return pushdown;
}

QString cAction::getCommand ()
{
  return command;
}

QString cAction::getCommand2 ()
{
  return command2;
}

void cAction::setIconName (const QString &s)
{
  iconname = s;
}

QString cAction::getIconName ()
{
  return iconname;
}

void cAction::insertToToolbar (int id)
{
  index = id;

  
  if(pushdown)
  {
    toolbar->insertButton (iconname, id, SIGNAL (toggled (int)), this, SLOT (performPushDownAction (int)), true, caption);
    toolbar->setToggle(id, true);
  }
  else
  {
    toolbar->insertButton (iconname, id, SIGNAL (clicked (int)), this, SLOT (performAction (int)), true, caption);
  }
}

void cAction::performAction (int)
{
  kmuddy->getSession (kmuddy->activeSession())->cmdproc()->processInput (command);
}

void cAction::performPushDownAction (int id)
{
  if(pushdown && toolbar->isButtonOn(id))
    kmuddy->getSession (kmuddy->activeSession())->cmdproc()->processInput (command);
  else if (pushdown && !(toolbar->isButtonOn(id)))
    kmuddy->getSession (kmuddy->activeSession())->cmdproc()->processInput (command2);
}

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/caction.cpp <==
/***************************************************************************
                          caction.cpp  -  action toolbar item
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Ne nov 3 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "caction.h"

#include "cactionmanager.h"
#include "csessionmanager.h"
#include "kmuddy.h"

// cAction and cActionManager are two VERY different things -mutter-

extern KMuddy *kmuddy;

#include <kconfig.h>
#include <ktoolbar.h>
#include <ktoolbarbutton.h>

cAction::cAction ()
{
  caption = "";
  command = "";
  iconname = "";
  command2 = "";
  pushdown = false;
  toolbar = kmuddy->atool ();
  index = -1;
}

cAction::~cAction ()
{
  //NOTHING!
}

cSaveableField *cAction::newInstance ()
{
  return new cAction;
}

void cAction::load (KConfig *config, const QString &group)
{
  config->setGroup (group);
  caption = config->readEntry ("Caption", "cmd_placeholder");
  command = config->readEntry ("Command", "");
  iconname = config->readEntry ("Icon name", "unknown");
  pushdown = config->readBoolEntry ("Pushdown", false);
  command2 = config->readEntry ("Command2", "");
  
}

void cAction::save (KConfig *config, const QString &group)
{
  config->setGroup (group);
  config->writeEntry ("Caption", caption);
  config->writeEntry ("Command", command);
  config->writeEntry ("Icon name", iconname);
  config->writeEntry ("Pushdown", pushdown);
  config->writeEntry ("Command2", command2);
}

void cAction::setCaption (const QString &s)
{
  caption = s;
}

QString cAction::getCaption ()
{
  return caption;
}

void cAction::setCommand (const QString &s)
{
  command = s;
}

void cAction::setCommand2 (const QString &s)
{
  command2 = s;
}

void cAction::setPushDown (bool how)
{
  pushdown = how;
}

bool cAction::isPushDown ()
{
  return pushdown;
}

QString cAction::getCommand ()
{
  return command;
}

QString cAction::getCommand2 ()
{
  return command2;
}

void cAction::setIconName (const QString &s)
{
  iconname = s;
}

QString cAction::getIconName ()
{
  return iconname;
}

void cAction::insertToToolbar (int id)
{
  index = id;

  
  if(pushdown)
  {
    toolbar->insertButton (iconname, id, SIGNAL (toggled (int)), this, SLOT (performPushDownAction (int)), true, caption);
    toolbar->setToggle(id, true);
  }
  else
  {
    toolbar->insertButton (iconname, id, SIGNAL (clicked (int)), this, SLOT (performAction (int)), true, caption);
  }
}

void cAction::performAction (int)
{
  cActionManager::self()->invokeEvent ("command", cSessionManager::self()->activeSession(), command);
}

void cAction::performPushDownAction (int id)
{
  if(pushdown && toolbar->isButtonOn(id))
    cActionManager::self()->invokeEvent ("command", cSessionManager::self()->activeSession(), command);
  else if (pushdown && !(toolbar->isButtonOn(id)))
    cActionManager::self()->invokeEvent ("command", cSessionManager::self()->activeSession(), command2);
}
